﻿Imports System
Imports System.Collections
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Web
Imports System.Web.SessionState
Imports System.Web.UI
Imports System.Web.UI.WebControls
Imports System.Web.UI.HtmlControls
Imports Telerik.Web.UI

Partial Public Class _Default
    Inherits System.Web.UI.Page
    Private _dockStateCleared As Boolean = False

    Private Property DockStyle() As String
        Get
            Return If(DirectCast(Session("DockStyle"), String), [String].Empty)
        End Get
        Set(ByVal value As String)
            Session("DockStyle") = value
        End Set
    End Property
    Private Property CurrentDockStates() As List(Of DockState)
        Get
            'Store the info about the added docks in the session. For real life
            ' applications we recommend using database or other storage medium 
            ' for persisting this information.
            Dim _currentDockStates As List(Of DockState) = DirectCast(Session("CurrentDockStatesMyPortal"), List(Of DockState))
            If [Object].Equals(_currentDockStates, Nothing) Then
                _currentDockStates = New List(Of DockState)()
                Session("CurrentDockStatesMyPortal") = _currentDockStates
            End If
            Return _currentDockStates
        End Get
        Set(ByVal value As List(Of DockState))
            Session("CurrentDockStatesMyPortal") = value
        End Set
    End Property

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As EventArgs)
        If Not IsPostBack Then
            DropDownZone.DataBind()
        End If
        'This is for test purposes only
        System.Threading.Thread.Sleep(1000)
    End Sub

    Public Function GetZones() As ArrayList

        Dim zones As New ArrayList()
        zones.Add(RadDockZone1)
        zones.Add(RadDockZone2)
        Return zones

    End Function

    Protected Sub Page_Init(ByVal sender As Object, ByVal e As EventArgs)
        'Recreate the docks in order to ensure their proper operation
        Dim i As Integer = 0
        While i < CurrentDockStates.Count
            If CurrentDockStates(i).Closed = False Then
                Dim dock As RadDock = CreateRadDockFromState(CurrentDockStates(i))
                'We will just add the RadDock control to the RadDockLayout.
                ' You could use any other control for that purpose, just ensure
                ' that it is inside the RadDockLayout control.
                ' The RadDockLayout control will automatically move the RadDock
                ' controls to their corresponding zone in the LoadDockLayout
                ' event (see below).


                'We want to save the dock state every time a dock is moved.
                CreateSaveStateTrigger(dock)
                'Load the selected widget
                LoadWidget(dock)

                RadDockLayout1.Controls.Add(dock)

                Dim con As New LiteralControl()
                con.Text = DockStyle

                dockStyles.Controls.Add(con)
            End If
            System.Math.Max(System.Threading.Interlocked.Increment(i), i - 1)
        End While
    End Sub

    Protected Sub RadDockLayout1_LoadDockLayout(ByVal sender As Object, ByVal e As DockLayoutEventArgs)
        'Populate the event args with the state information. The RadDockLayout control
        ' will automatically move the docks according that information.
        For Each state As DockState In CurrentDockStates
            e.Positions(state.UniqueName) = state.DockZoneID
            e.Indices(state.UniqueName) = state.Index
        Next
    End Sub

    Protected Sub RadDockLayout1_SaveDockLayout(ByVal sender As Object, ByVal e As DockLayoutEventArgs)
        If Not _dockStateCleared Then
            'Save the dock state in the session. This will enable us 
            ' to recreate the dock in the next Page_Init.
            CurrentDockStates = RadDockLayout1.GetRegisteredDocksState()
        Else
            'the clear state button was clicked, so we refresh the page and start over.
            Response.Redirect(Request.RawUrl, False)
        End If
    End Sub

    Private Function CreateRadDockFromState(ByVal state As DockState) As RadDock
        Dim dock As New RadDock()
        dock.DockMode = DockMode.Docked
        dock.ID = String.Format("RadDock{0}", state.UniqueName)
        dock.ApplyState(state)

        dock.Commands.Add(New DockCloseCommand())
        dock.Commands.Add(New DockExpandCollapseCommand())


        Return dock
    End Function

    Private Function CreateRadDock() As RadDock
        Dim docksCount As Integer = CurrentDockStates.Count

        Dim dock As New RadDock()
        dock.DockMode = DockMode.Docked
        dock.UniqueName = Guid.NewGuid().ToString()
        dock.ID = String.Format("RadDock{0}", dock.UniqueName)
        dock.Title = "Dock"
        dock.Text = String.Format("Added at {0}", DateTime.Now)
        dock.Width = Unit.Pixel(300)



        dock.Commands.Add(New DockCloseCommand())
        dock.Commands.Add(New DockExpandCollapseCommand())

        Return dock
    End Function

    Private Sub CreateSaveStateTrigger(ByVal dock As RadDock)
        'Ensure that the RadDock control will initiate postback
        ' when its position changes on the client or any of the commands is clicked.
        'Using the trigger we will "ajaxify" that postback.
        dock.AutoPostBack = True
        dock.CommandsAutoPostBack = True

        Dim updatedControl As New AjaxUpdatedControl()
        updatedControl.ControlID = "Panel1"

        Dim setting1 As New AjaxSetting(dock.ID)
        setting1.EventName = "DockPositionChanged"
        setting1.UpdatedControls.Add(updatedControl)

        Dim setting2 As New AjaxSetting(dock.ID)
        setting2.EventName = "Command"
        setting2.UpdatedControls.Add(updatedControl)

        RadAjaxManager1.AjaxSettings.Add(setting1)
        RadAjaxManager1.AjaxSettings.Add(setting2)
    End Sub

    Private Sub LoadWidget(ByVal dock As RadDock)
        If String.IsNullOrEmpty(dock.Tag) Then
            Return
        End If
        Dim widget As Control = LoadControl(dock.Tag)
        dock.ContentContainer.Controls.Add(widget)
    End Sub


    Protected Sub ButtonAddDock_Click(ByVal sender As Object, ByVal e As EventArgs)
        Dim dock As RadDock = CreateRadDock()
        'find the target zone and add the new dock there
        Dim dz As RadDockZone = DirectCast(FindControl(DropDownZone.SelectedItem.Text), RadDockZone)


        dz.Controls.Add(dock)


        CreateSaveStateTrigger(dock)

        'Load the selected widget in the RadDock control
        dock.Tag = DroptDownWidget.SelectedValue
        LoadWidget(dock)

        Dim dockPosition As Integer = Convert.ToInt32(ddlPosition.SelectedValue)
        If dockCheckBox.Checked Then
            Dim con As New LiteralControl()
            con.Text = "#" + dock.ClientID + " .rdContent" + "{overflow: hidden !important;}"
            DockStyle += " " + con.Text
            dockStyles.Controls.Add(con)
        End If

        ScriptManager.RegisterStartupScript(Me, Me.[GetType](), "MoveDock", String.Format("function _moveDock() {{" & vbCr & vbLf & vbTab & vbTab & vbTab & "        " & vbTab & "Sys.Application.remove_load(_moveDock);" & vbCr & vbLf & vbTab & vbTab & vbTab & vbTab & "        $find('{1}').dock($find('{0}'),{2});" & vbCr & vbLf & vbTab & vbTab & vbTab & "            }};" & vbCr & vbLf & vbTab & vbTab & vbTab & "            Sys.Application.add_load(_moveDock);", dock.ClientID, DropDownZone.SelectedValue, dockPosition), True)


        '            //move dock to the last place in the RadDockZone
        '            ScriptManager.RegisterStartupScript(this,
        '                this.GetType(),
        '                "MoveDock",
        '            string.Format(@"function _moveDock() {{
        '        	Sys.Application.remove_load(_moveDock);
        '	        $find('{1}').dock($find('{0}'),{2});
        '            }};
        '            Sys.Application.add_load(_moveDock);", dock.ClientID, DropDownZone.SelectedValue, dz.Docks.Count),
        '            true);

    End Sub
    Protected Sub ButtonPostBack_Click(ByVal sender As Object, ByVal e As EventArgs)
        'normal postback
    End Sub
    Protected Sub ButtonClear_Click(ByVal sender As Object, ByVal e As EventArgs)
        'clear docks state from the session
        CurrentDockStates.Clear()
        _dockStateCleared = True
    End Sub

End Class
